==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectLexval.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectlexval_h
#define objectlexval_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
struct s_lexval {
  t_adms _adms;
  char* _string;
  int _string_isdefault : 1;
  char* _filename;
  int _filename_isdefault : 1;
  int _l;
  int _l_isdefault : 1;
  int _fpos;
  int _fpos_isdefault : 1;
  int _lpos;
  int _lpos_isdefault : 1;
};

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_lexval_getuid (p_lexval mylexval);
win32_interface gboolean adms_lexval_cmp (p_lexval mylexval,p_lexval reflexval);
win32_interface p_lexval adms_lexval_new_1 (char* mystring,char* myfilename,int myl,int myfpos,int mylpos);
#define adms_lexval_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_lexval_free(item)\
{\
  free(item->_string);\
  free(item->_filename);\
  free(item);\
}
win32_interface p_adms adms_lexval_new_impl (p_adms arguments[]);
win32_interface p_lexval adms_lexval_impl (void* member);
#define adms_lexval(member) ((p_lexval) (member))
#define adms_lexval_new adms_lexval_new_1
#define adms_lexval_isdefault_string(lexval) (adms_lexval(lexval)->_string_isdefault)
#define adms_lexval_valueof_string(lexval) (adms_lexval(lexval)->_string)
#define adms_lexval_isdefault_filename(lexval) (adms_lexval(lexval)->_filename_isdefault)
#define adms_lexval_valueof_filename(lexval) (adms_lexval(lexval)->_filename)
#define adms_lexval_isdefault_l(lexval) (adms_lexval(lexval)->_l_isdefault)
#define adms_lexval_valueof_l(lexval) (adms_lexval(lexval)->_l)
#define adms_lexval_isdefault_fpos(lexval) (adms_lexval(lexval)->_fpos_isdefault)
#define adms_lexval_valueof_fpos(lexval) (adms_lexval(lexval)->_fpos)
#define adms_lexval_isdefault_lpos(lexval) (adms_lexval(lexval)->_lpos_isdefault)
#define adms_lexval_valueof_lpos(lexval) (adms_lexval(lexval)->_lpos)
#define adms_lexval_valueof_adms(lexval) ((p_adms)lexval)
#define adms_lexval_valueto_string(a,b) ((p_lexval)a)->_string=(b)
win32_interface void adms_lexval_valueto_string_impl (p_lexval mylexval,char* _string);
#define adms_lexval_valueto_filename(a,b) ((p_lexval)a)->_filename=(b)
win32_interface void adms_lexval_valueto_filename_impl (p_lexval mylexval,char* _filename);
#define adms_lexval_valueto_l(a,b) ((p_lexval)a)->_l=(b)
win32_interface void adms_lexval_valueto_l_impl (p_lexval mylexval,int _l);
#define adms_lexval_valueto_fpos(a,b) ((p_lexval)a)->_fpos=(b)
win32_interface void adms_lexval_valueto_fpos_impl (p_lexval mylexval,int _fpos);
#define adms_lexval_valueto_lpos(a,b) ((p_lexval)a)->_lpos=(b)
win32_interface void adms_lexval_valueto_lpos_impl (p_lexval mylexval,int _lpos);
#endif /* objectlexval_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectLexval.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectlexval_h
#define objectlexval_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
struct s_lexval {
  t_adms _adms;
  char* _string;
  int _string_isdefault : 1;
  char* _filename;
  int _filename_isdefault : 1;
  int _l;
  int _l_isdefault : 1;
  int _fpos;
  int _fpos_isdefault : 1;
};

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_lexval_uid (p_lexval mylexval);
win32_interface int adms_lexval_cmp (p_lexval mylexval,p_lexval reflexval);
win32_interface p_lexval adms_lexval_new(const char* mystring,const char* myfilename,int myl,int myfpos);
win32_interface p_adms adms_lexval_new_impl (p_adms arguments[]);
#define adms_lexval(member) ((p_lexval) (member))
#define adms_lexval_isdefault_string(lexval) (adms_lexval(lexval)->_string_isdefault)
#define adms_lexval_valueof_string(lexval) (adms_lexval(lexval)->_string)
#define adms_lexval_isdefault_filename(lexval) (adms_lexval(lexval)->_filename_isdefault)
#define adms_lexval_valueof_filename(lexval) (adms_lexval(lexval)->_filename)
#define adms_lexval_isdefault_l(lexval) (adms_lexval(lexval)->_l_isdefault)
#define adms_lexval_valueof_l(lexval) (adms_lexval(lexval)->_l)
#define adms_lexval_isdefault_fpos(lexval) (adms_lexval(lexval)->_fpos_isdefault)
#define adms_lexval_valueof_fpos(lexval) (adms_lexval(lexval)->_fpos)
#define adms_lexval_valueof_adms(lexval) ((p_adms)lexval)
win32_interface inline void adms_lexval_valueto_string (p_lexval mylexval,const char* _string);
win32_interface inline void adms_lexval_valueto_filename (p_lexval mylexval,const char* _filename);
win32_interface inline void adms_lexval_valueto_l (p_lexval mylexval,int _l);
win32_interface inline void adms_lexval_valueto_fpos (p_lexval mylexval,int _fpos);
win32_interface inline void adms_lexval_free(p_lexval mylexval);
#endif /* objectlexval_h */
